@@ -1,14 +1,19 @@
-/****************************************************************************
- * Header for the main functions.
- * Copyright (C) 2004 Joe Wingbermuehle
- ****************************************************************************/
+/**
+ * @file main.h
+ * @author Joe Wingbermuehle
+ * @date 2004-2006
+ *
+ * @brief Header for the main functions.
+ *
+ */
 
 #ifndef MAIN_H
 #define MAIN_H
 
+/** Enumeration of focus models. */
 typedef enum {
-	FOCUS_SLOPPY              = 0,
-	FOCUS_CLICK               = 1
+   FOCUS_SLOPPY              = 0,
+   FOCUS_CLICK               = 1
 } FocusModelType;
 
 extern Display *display;
@@ -18,6 +23,7 @@ extern int rootDepth;
 extern int rootScreen;
 extern Colormap rootColormap;
 extern Visual *rootVisual;
+extern GC rootGC;
 extern int colormapCount;
 
 extern char *exitCommand;
@@ -27,6 +33,7 @@ extern unsigned int currentDesktop;
 
 extern int shouldExit;
 extern int shouldRestart;
+extern int isRestarting;
 
 extern int initializing;
 
@@ -46,5 +53,5 @@ extern int haveShape;
 extern int shapeEvent;
 #endif
 
-#endif
+#endif /* MAIN_H */
 
